@@ -1,19 +1,3 @@
-# This file is part of CairoSVG
-# Copyright © 2010-2018 Kozea
-#
-# This library is free software: you can redistribute it and/or modify it under
-# the terms of the GNU Lesser General Public License as published by the Free
-# Software Foundation, either version 3 of the License, or (at your option) any
-# later version.
-#
-# This library is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-# FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
-# details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with CairoSVG.  If not, see <http://www.gnu.org/licenses/>.
-
 """
 Command-line interface to CairoSVG.
 
@@ -48,6 +32,14 @@ def main(argv=None, stdout=None, stdin=None):
         help='height of the parent container in pixels')
     parser.add_argument(
         '-s', '--scale', default=1, type=float, help='output scaling factor')
+    parser.add_argument(
+        '-b', '--background', metavar='COLOR', help='output background color')
+    parser.add_argument(
+        '-n', '--negate-colors', action='store_true',
+        help='replace every vector color with its complement')
+    parser.add_argument(
+        '-i', '--invert-images', action='store_true',
+        help='replace every raster pixel with its complementary color')
     parser.add_argument(
         '-u', '--unsafe', action='store_true',
         help='resolve XML entities and allow very large files '
@@ -65,6 +57,9 @@ def main(argv=None, stdout=None, stdin=None):
     kwargs = {
         'parent_width': options.width, 'parent_height': options.height,
         'dpi': options.dpi, 'scale': options.scale, 'unsafe': options.unsafe,
+        'background_color': options.background,
+        'negate_colors': options.negate_colors,
+        'invert_images': options.invert_images,
         'output_width': options.output_width,
         'output_height': options.output_height}
     stdin = stdin or sys.stdin
