@@ -1,19 +1,3 @@
-# This file is part of CairoSVG
-# Copyright © 2010-2018 Kozea
-#
-# This library is free software: you can redistribute it and/or modify it under
-# the terms of the GNU Lesser General Public License as published by the Free
-# Software Foundation, either version 3 of the License, or (at your option) any
-# later version.
-#
-# This library is distributed in the hope that it will be useful, but WITHOUT
-# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
-# FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License for more
-# details.
-#
-# You should have received a copy of the GNU Lesser General Public License
-# along with CairoSVG.  If not, see <http://www.gnu.org/licenses/>.
-
 """
 SVG Parser.
 
@@ -49,11 +33,15 @@ NOT_INHERITED_ATTRIBUTES = frozenset((
     'stop-opacity',
     'style',
     'transform',
+    'transform-origin',
     'viewBox',
     'width',
     'x',
     'y',
+    'dx',
+    'dy',
     '{http://www.w3.org/1999/xlink}href',
+    'href',
 ))
 
 COLOR_ATTRIBUTES = frozenset((
@@ -270,9 +258,10 @@ class Node(dict):
             trailing_space = self.text.endswith(' ')
         for child_element in element.iter_children():
             child = child_element.etree_element
-            if child.tag == '{http://www.w3.org/2000/svg}tref':
-                url = parse_url(child.get(
-                    '{http://www.w3.org/1999/xlink}href')).geturl()
+            if child.tag in ('{http://www.w3.org/2000/svg}tref', 'tref'):
+                href = child.get(
+                    '{http://www.w3.org/1999/xlink}href', child.get('href'))
+                url = parse_url(href).geturl()
                 child_tree = Tree(
                     url=url, url_fetcher=self.url_fetcher, parent=self,
                     unsafe=self.unsafe)
@@ -320,6 +309,9 @@ class Node(dict):
 
         return children, trailing_space
 
+    def get_href(self):
+        return self.get('{http://www.w3.org/1999/xlink}href', self.get('href'))
+
 
 class Tree(Node):
     """SVG tree."""
@@ -381,9 +373,12 @@ class Tree(Node):
         else:
             raise TypeError(
                 'No input. Use one of bytestring, file_obj or url.')
-        if parent and self.url == parent.url:
+        self_is_parent = (
+            (parent and self.url == parent.url) or
+            (url and url.startswith('#') and not self.url))
+        if self_is_parent:
             root_parent = parent
-            while root_parent.parent:
+            while root_parent.parent is not None:
                 root_parent = root_parent.parent
             tree = root_parent.xml_tree
         else:
